==> SexyMap-v9.2.15.zip: SexyMap/localization/zhTW.lua <==

if GetLocale() ~= "zhTW" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "1、背景"
L["2. Border"] = "2、邊框"
L["3. Artwork"] = "3、藝術裝飾"
L["4. Overlay"] = "4、覆蓋"
L["5. Highlight"] = "5、高亮"
L["Add Blend (additive)"] = "添加混合（附加式）"
L["Addon Buttons"] = "插件按鈕"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "一個共用設定檔已存在，你將會切換至該設定檔並重新載入UI，你確定？"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "令 SexyMap 能夠拖曳迷你地圖上的按鈕。假如你想用其他插件來拖曳，關閉這個功能"
L["Alpha Key (1-bit alpha)"] = "測試鍵（1位測試）"
L["Always"] = "總是顯示"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "你確定要切換回使用角色個別設定檔？這會重新載入你的插件。"
L["Armored Man"] = "耐久度"
L["A static amount to rotate the texture by."] = "材質靜態旋轉量"
L["Auto Zoom-Out Delay"] = "自動縮小延遲"
L["Backdrop Color"] = "背景顏色"
L["Backdrop Insets"] = "背景鑲邊"
L["Background Color"] = "背景顏色"
L["Background/edge"] = "背景/邊緣"
L["Background Texture"] = "背景材質"
L["Blend Mode"] = "混合模式"
L["Blend (normal)"] = "混合效果（普通）"
L["Border Color"] = "邊框色彩"
L["Border Edge Size"] = "邊框角落尺寸"
L["Borders"] = "邊框"
L["Border Texture"] = "邊框材質"
L["Boss Frames"] = "首領框架"
L["Buttons"] = "按鈕"
L["Calendar"] = "行事曆"
L["Challenge Mode Button (When Available)"] = "挑戰模式按鈕(當可用時)"
L["Circle"] = "圓形"
L["Clamp to screen"] = "不超出螢幕範圍"
L["Clear & start over"] = "重置"
L["Clear the current borders and start fresh"] = "清除當前邊框重新開始設置"
L["Clock"] = "時鐘"
L["Coordinates"] = "坐標"
L["Copy a Profile"] = "複製設定檔"
L["Copying this profile will reload your UI, are you sure?"] = "複製這個設定檔會重新載入你的UI，你確定？"
L["Create a new border"] = "創建新邊框"
L["Current Borders"] = "當前邊框"
L["Default Presets"] = "預設外觀" -- Needs review
L["Delete"] = "刪除"
L["Delete a Profile"] = "刪除設定檔"
L["Diamond"] = "鑽石形"
L["Disable (opaque)"] = "禁用（不透明）"
L["Disable Rotation"] = "關閉旋轉"
L["Drag Radius"] = "拖曳半徑"
L["Dungeon Difficulty Indicator (When Available)"] = "副本難度指示（可用時）"
L["Dynamic Buttons"] = "動態按鈕"
L["Enable"] = "啟用"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "啟用迷你地圖的背景與邊框，便於設定方形邊框。"
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "啟用 HUD 式迷你地圖。這個對采集資源很有好處，但是因為技術上的關係，HUD 地圖和原本的迷你地圖不能一起顯示。顯示 HUD 地圖會關閉原本的迷你地圖。"
L["Enable Coordinates"] = "啟用坐標顯示"
L["Enable Hudmap"] = "啟用 HUD 地圖"
L["Enable Minimap Fader"] = "啟用小地圖淡出"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "輸入一個名稱以創建一個新的邊框。可以用任何你想用來幫助你識別此邊框的名稱"
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "請輸入要使用的材質完整路徑。建議使用如 TexBrowser 來尋找可用的材質。"
L["Entry Options"] = "基本設置"
L["Faded Circle (Large)"] = "圓形淡出（大）"
L["Faded Circle (Small)"] = "圓形淡出（小）"
L["Faded Square"] = "方形淡出"
L["Fader"] = "淡出"
L["Font"] = "字型"
L["Font Color"] = "字型色彩"
L["Font Size"] = "字型大小"
L["Force a square texture. Fixed distortion on square textures."] = "強制使用方形材質，修正因方形材質產生的變形。"
L["Garrison Button (When Available)"] = "要塞按鈕（當可用時）"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "公會副本難度(當可用時)"
L["Heart"] = "心形"
L["Height"] = "高度"
L["Hexagon"] = "六邊形"
L["Hide default border"] = "隱藏默認邊框"
L["Hide the default border on the minimap."] = "隱藏小地圖默認的邊框"
L["Horizontal Nudge"] = "橫向位移"
L["Horizontal Position"] = "橫向位置"
L["Hover Opacity"] = "滑鼠懸停時不透明度"
L["HUD Color"] = "HUD 顏色"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "如果你放大地圖，在選擇的一段時間(秒)之後這功能會自動縮小。使用數值0會禁用自動縮小。"
L["Keybinding"] = "綁定熱鍵"
L["Layer"] = "層級"
L["Let SexyMap control button visibility"] = "SexyMap 管理按鈕可見性"
L["Let SexyMap handle button dragging"] = "SexyMap 接管按鈕拖曳"
L["Lock Button Dragging"] = "鎖定按鈕拖曳"
L["Lock Minimap"] = "鎖定小地圖"
L["Map Button"] = "世界地圖按鈕"
L["Minimap shape"] = "迷你地圖外觀"
L["Mod Blend (modulative)"] = "模塊混合（模塊式）"
L["Movers"] = "描點"
L["Name"] = "名稱"
L["Never"] = "不顯示"
L["New Mail Indicator (When Available)"] = "新郵件指示（可用時）"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "無共用設定檔存在，目前的設定檔將複製至共用設定檔並使用，你確定？這會重新載入你的UI。"
L["Normal Opacity"] = "常規狀態時不透明度"
L["Objectives Tracker"] = "物品追蹤"
L["Octagon"] = "八邊形"
L["On Hover"] = "懸停時"
L["Opacity"] = "不透明度"
L["Open TexBrowser"] = "開啟 TexBrowser"
L["Ping"] = "點擊小地圖"
L["Preset"] = "配置檔"
L["Prevent the minimap from being moved off the screen"] = "預防從小地圖被移出螢幕"
L["Profiles"] = "配置檔"
L["Queue Status (PvP/LFG) Button (When Available)"] = "序列狀態(PvP/LFG)按鈕(當啟用時)"
L["Quickly change the look of your minimap by using a minimap preset."] = "使用預設外觀設定快速更改小地圖的外觀。" -- Needs review
L["Really delete this border?"] = "確定刪除此邊框？"
L["Really delete this preset? This can't be undone."] = "此動作無法再回復，確定要刪除此設定檔？"
L["Really delete this profile?"] = "確定要刪除這個設定檔?"
L["(Requires button visibility control in the Buttons menu)"] = "（在按鈕選單的需求按鈕能見度控制）"
L["Reset Current Profile"] = "重置目前設定檔"
L["Resetting this profile will reload your UI, are you sure?"] = "重置設定檔將重新載入你的UI，你確定？"
L["Right Click Configure"] = "右鍵點擊設定"
L["Right clicking the map will open the SexyMap options"] = "右鍵點擊地圖開啟SexyMap設定"
L["Rotation Speed (seconds)"] = "旋轉速度"
L["Rounded - Bottom"] = "方形圓角-下"
L["Rounded - Bottom Left"] = "方形圓角-左下"
L["Rounded - Bottom Right"] = "方形圓角-右下"
L["Rounded - Left"] = "方形圓角-左"
L["Rounded - Right"] = "方形圓角-右"
L["Rounded - Top"] = "方形圓角-上"
L["Rounded - Top Left"] = "方形圓角-左上"
L["Rounded - Top Right"] = "方形圓角-右上"
L["Route 66"] = "66路形"
L["Save current settings as preset..."] = "儲存目前設定於配置檔"
L["Scale"] = "縮放"
L["Select a preset to load settings from. This will erase any of your current borders."] = "選擇配置檔以載入設定值，這將會清除你目前的邊框設定。"
L["Select preset to load"] = "選擇要載入的配置檔"
L["SharedMedia Border"] = "SharedMedia 邊框"
L["SharedMedia Texture"] = "SharedMedia 材質"
L["Show inside chat"] = "在聊天窗口顯示"
L["Show North Tag"] = "顯示北方標籤"
L["Show on minimap"] = "在迷你地圖顯示"
L["Show %s:"] = "顯示%s："
L["Show who pinged"] = "顯示誰點擊地圖"
L["Snowflake"] = "雪花形"
L["Spice up your minimap with some sexy options."] = "讓你有更香豔的一些性感小地圖設定。"
L["Square"] = "方形"
L["Standard Buttons"] = "標準按鈕"
L["Static Rotation"] = "靜態旋轉"
L["TexBrowser Not Installed"] = "尚未安裝 TexBrowser"
L["Text Color"] = "文本顏色"
L["Texture"] = "材質"
L["Texture Options"] = "材質設定"
L["Texture Path"] = "材質路徑"
L["Texture Tint"] = "材質顏色"
L["Text Width"] = "文字寬度"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "HudMap支援幾個插件。如果你有以下安裝的任何插件，它們就會顯示在HudMap。"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "材質旋轉速度，設定為 0 則停止旋轉"
L["This will wipe out any current settings!"] = "這將會清除你目前的設定值！"
L["Tile Background"] = "標題背景"
L["Tile Size"] = "標題大小"
L["Toggle HudMap On/Off"] = "切換HudMap開/關"
L["Tracking Button"] = "追蹤技能按鈕"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "假如你用其他插件控制隱藏，關閉這個功能"
L["Use Global Profile"] = "使用共用設定檔"
L["User-Submitted Presets"] = "玩家提供的外觀" -- Needs review
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "當你想要所有角色具有相同外觀則使用共用設定檔，或是使用角色個別設定檔讓不同角色具有不同外觀。"
L["Vehicle Seat"] = "載具座位"
L["Vertical Nudge"] = "垂直輕移"
L["Vertical Position"] = "垂直位置"
L["Visibility"] = "能見度"
L["Width"] = "寬度"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "設定你喜歡的迷你地圖設定背景與邊框檔案，便於建立迷你地圖為靜態方形。"
L["Zone Text"] = "地區文字"
L["Zoom In Button"] = "放大按鈕"
L["Zoom Out Button"] = "縮小按鈕"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP 佔領狀態條"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"

==> SexyMap-v11.0.1.zip: SexyMap/localization/zhTW.lua <==

if GetLocale() ~= "zhTW" then return end
local _, sm = ...
local L = sm.L
--L.dayNightButton = "Day/Night Indicator"
--L.classicLFGButton = "Classic LFG Button (When Available)"
--L.classicPVPButton = "Classic PvP Button (When Available)"
L["1. Background"] = "1、背景"
L["2. Border"] = "2、邊框"
L["3. Artwork"] = "3、藝術裝飾"
L["4. Overlay"] = "4、覆蓋"
L["5. Highlight"] = "5、高亮"
L["Add Blend (additive)"] = "添加混合（附加式）"
L["Addon Buttons"] = "插件按鈕"
L["A global profile already exists. You will be switched over to it and your UI will be reloaded, are you sure?"] = "一個共用設定檔已存在，你將會切換至該設定檔並重新載入UI，你確定？"
L["Allow SexyMap to assume drag ownership for buttons attached to the minimap. Turn this off if you have another mod that you want to use to position your minimap buttons."] = "令 SexyMap 能夠拖曳迷你地圖上的按鈕。假如你想用其他插件來拖曳，關閉這個功能"
L["Alpha Key (1-bit alpha)"] = "測試鍵（1位測試）"
L["Always"] = "總是顯示"
L["Are you sure you want to switch back to using a character specific profile? This will reload your UI."] = "你確定要切換回使用角色個別設定檔？這會重新載入你的插件。"
L["Armored Man"] = "耐久度"
L["A static amount to rotate the texture by."] = "材質靜態旋轉量"
L["Auto Zoom-Out Delay"] = "自動縮小延遲"
L["Backdrop Color"] = "背景顏色"
L["Backdrop Insets"] = "背景鑲邊"
L["Background Color"] = "背景顏色"
L["Background/edge"] = "背景/邊緣"
L["Background Texture"] = "背景材質"
L["Blend Mode"] = "混合模式"
L["Blend (normal)"] = "混合效果（普通）"
L["Border Color"] = "邊框色彩"
L["Border Edge Size"] = "邊框角落尺寸"
L["Borders"] = "邊框"
L["Border Texture"] = "邊框材質"
L["Boss Frames"] = "首領框架"
L["Buttons"] = "按鈕"
L["Calendar"] = "行事曆"
L["Challenge Mode Button (When Available)"] = "挑戰模式按鈕(當可用時)"
L["Circle"] = "圓形"
L["Clamp to screen"] = "不超出螢幕範圍"
L["Clear & start over"] = "重置"
L["Clear the current borders and start fresh"] = "清除當前邊框重新開始設置"
L["Clock"] = "時鐘"
L["Coordinates"] = "坐標"
L["Copy a Profile"] = "複製設定檔"
L["Copying this profile will reload your UI, are you sure?"] = "複製這個設定檔會重新載入你的UI，你確定？"
L["Create a new border"] = "創建新邊框"
L["Current Borders"] = "當前邊框"
L["Default Presets"] = "預設外觀" -- Needs review
L["Delete"] = "刪除"
L["Delete a Profile"] = "刪除設定檔"
L["Diamond"] = "鑽石形"
L["Disable (opaque)"] = "禁用（不透明）"
L["Disable Rotation"] = "關閉旋轉"
L["Drag Radius"] = "拖曳半徑"
L["Dungeon Difficulty Indicator (When Available)"] = "副本難度指示（可用時）"
L["Dynamic Buttons"] = "動態按鈕"
L["Enable"] = "啟用"
L["Enable a backdrop and border for the minimap. This will let you set square borders more easily."] = "啟用迷你地圖的背景與邊框，便於設定方形邊框。"
L["Enable a HUD minimap. This is very useful for gathering resources, but for technical reasons, the HUD map and the normal minimap can't be shown at the same time. Showing the HUD map will turn off the normal minimap."] = "啟用 HUD 式迷你地圖。這個對采集資源很有好處，但是因為技術上的關係，HUD 地圖和原本的迷你地圖不能一起顯示。顯示 HUD 地圖會關閉原本的迷你地圖。"
L["Enable Coordinates"] = "啟用坐標顯示"
L["Enable Hudmap"] = "啟用 HUD 地圖"
L["Enable Minimap Fader"] = "啟用小地圖淡出"
L["Enter a name to create a new border. The name can be anything you like to help you identify that border."] = "輸入一個名稱以創建一個新的邊框。可以用任何你想用來幫助你識別此邊框的名稱"
L["Enter the full path to a texture to use. It's recommended that you use something like |cffff6600TexBrowser|r to find textures to use."] = "請輸入要使用的材質完整路徑。建議使用如 TexBrowser 來尋找可用的材質。"
L["Entry Options"] = "基本設置"
L["Faded Circle (Large)"] = "圓形淡出（大）"
L["Faded Circle (Small)"] = "圓形淡出（小）"
L["Faded Square"] = "方形淡出"
L["Fader"] = "淡出"
L["Font"] = "字型"
L["Font Color"] = "字型色彩"
L["Font Size"] = "字型大小"
L["Force a square texture. Fixed distortion on square textures."] = "強制使用方形材質，修正因方形材質產生的變形。"
L["Garrison Button (When Available)"] = "要塞按鈕（當可用時）"
L["Guild Dungeon Difficulty Indicator (When Available)"] = "公會副本難度(當可用時)"
L["Heart"] = "心形"
L["Height"] = "高度"
L["Hexagon"] = "六邊形"
L["Hide default border"] = "隱藏默認邊框"
L["Hide the default border on the minimap."] = "隱藏小地圖默認的邊框"
L["Horizontal Nudge"] = "橫向位移"
L["Horizontal Position"] = "橫向位置"
L["Hover Opacity"] = "滑鼠懸停時不透明度"
L["HUD Color"] = "HUD 顏色"
L["If you zoom into the map, this feature will automatically zoom out after the selected period of time (seconds). Using a value of 0 will disable Auto Zoom-Out."] = "如果你放大地圖，在選擇的一段時間(秒)之後這功能會自動縮小。使用數值0會禁用自動縮小。"
L["Keybinding"] = "綁定熱鍵"
L["Layer"] = "層級"
L["Let SexyMap control button visibility"] = "SexyMap 管理按鈕可見性"
L["Let SexyMap handle button dragging"] = "SexyMap 接管按鈕拖曳"
L["Lock Button Dragging"] = "鎖定按鈕拖曳"
L["Lock Minimap"] = "鎖定小地圖"
L["Map Button"] = "世界地圖按鈕"
L["Minimap shape"] = "迷你地圖外觀"
L["Mod Blend (modulative)"] = "模塊混合（模塊式）"
L["Movers"] = "描點"
L["Name"] = "名稱"
L["Never"] = "不顯示"
L["New Mail Indicator (When Available)"] = "新郵件指示（可用時）"
L["No global profile exists. Your current profile will be copied over and used as the global profile, are you sure? This will also reload your UI."] = "無共用設定檔存在，目前的設定檔將複製至共用設定檔並使用，你確定？這會重新載入你的UI。"
L["Normal Opacity"] = "常規狀態時不透明度"
L["Objectives Tracker"] = "物品追蹤"
L["Octagon"] = "八邊形"
L["On Hover"] = "懸停時"
L["Opacity"] = "不透明度"
L["Open TexBrowser"] = "開啟 TexBrowser"
L["Ping"] = "點擊小地圖"
L["Preset"] = "配置檔"
L["Prevent the minimap from being moved off the screen"] = "預防從小地圖被移出螢幕"
L["Profiles"] = "配置檔"
L["Queue Status (PvP/LFG) Button (When Available)"] = "序列狀態(PvP/LFG)按鈕(當啟用時)"
L["Quickly change the look of your minimap by using a minimap preset."] = "使用預設外觀設定快速更改小地圖的外觀。" -- Needs review
L["Really delete this border?"] = "確定刪除此邊框？"
L["Really delete this preset? This can't be undone."] = "此動作無法再回復，確定要刪除此設定檔？"
L["Really delete this profile?"] = "確定要刪除這個設定檔?"
L["(Requires button visibility control in the Buttons menu)"] = "（在按鈕選單的需求按鈕能見度控制）"
L["Reset Current Profile"] = "重置目前設定檔"
L["Resetting this profile will reload your UI, are you sure?"] = "重置設定檔將重新載入你的UI，你確定？"
L["Right Click Configure"] = "右鍵點擊設定"
L["Right clicking the map will open the SexyMap options"] = "右鍵點擊地圖開啟SexyMap設定"
L["Rotation Speed (seconds)"] = "旋轉速度"
L["Rounded - Bottom"] = "方形圓角-下"
L["Rounded - Bottom Left"] = "方形圓角-左下"
L["Rounded - Bottom Right"] = "方形圓角-右下"
L["Rounded - Left"] = "方形圓角-左"
L["Rounded - Right"] = "方形圓角-右"
L["Rounded - Top"] = "方形圓角-上"
L["Rounded - Top Left"] = "方形圓角-左上"
L["Rounded - Top Right"] = "方形圓角-右上"
L["Route 66"] = "66路形"
L["Save current settings as preset..."] = "儲存目前設定於配置檔"
L["Scale"] = "縮放"
L["Select a preset to load settings from. This will erase any of your current borders."] = "選擇配置檔以載入設定值，這將會清除你目前的邊框設定。"
L["Select preset to load"] = "選擇要載入的配置檔"
L["SharedMedia Border"] = "SharedMedia 邊框"
L["SharedMedia Texture"] = "SharedMedia 材質"
L["Show inside chat"] = "在聊天窗口顯示"
L["Show North Tag"] = "顯示北方標籤"
L["Show on minimap"] = "在迷你地圖顯示"
L["Show %s:"] = "顯示%s："
L["Show who pinged"] = "顯示誰點擊地圖"
L["Snowflake"] = "雪花形"
L["Spice up your minimap with some sexy options."] = "讓你有更香豔的一些性感小地圖設定。"
L["Square"] = "方形"
L["Standard Buttons"] = "標準按鈕"
L["Static Rotation"] = "靜態旋轉"
L["TexBrowser Not Installed"] = "尚未安裝 TexBrowser"
L["Text Color"] = "文本顏色"
L["Texture"] = "材質"
L["Texture Options"] = "材質設定"
L["Texture Path"] = "材質路徑"
L["Texture Tint"] = "材質顏色"
L["Text Width"] = "文字寬度"
L["The HudMap supports several addons. If you have any of the addons below installed, they will be shown on the HudMap."] = "HudMap支援幾個插件。如果你有以下安裝的任何插件，它們就會顯示在HudMap。"
L["The time it takes (in seconds) to complete one rotation. A setting of 0 turns off rotation."] = "材質旋轉速度，設定為 0 則停止旋轉"
L["This will wipe out any current settings!"] = "這將會清除你目前的設定值！"
L["Tile Background"] = "標題背景"
L["Tile Size"] = "標題大小"
L["Toggle HudMap On/Off"] = "切換HudMap開/關"
L["Tracking Button"] = "追蹤技能按鈕"
L["Turn this off if you want another mod to handle which buttons are visible on the minimap."] = "假如你用其他插件控制隱藏，關閉這個功能"
L["Use Global Profile"] = "使用共用設定檔"
L["User-Submitted Presets"] = "玩家提供的外觀" -- Needs review
L["Use the global profile if you want the same look on every character, or use a character-specific profile for a unique look on each character."] = "當你想要所有角色具有相同外觀則使用共用設定檔，或是使用角色個別設定檔讓不同角色具有不同外觀。"
L["Vehicle Seat"] = "載具座位"
L["Vertical Nudge"] = "垂直輕移"
L["Vertical Position"] = "垂直位置"
L["Visibility"] = "能見度"
L["Width"] = "寬度"
L["You can set a background and edge file for the minimap like you would with any frame. This is useful when you want to create static square backdrops for your minimap."] = "設定你喜歡的迷你地圖設定背景與邊框檔案，便於建立迷你地圖為靜態方形。"
L["Zone Text"] = "地區文字"
L["Zoom In Button"] = "放大按鈕"
L["Zoom Out Button"] = "縮小按鈕"

-- Buttons.lua
--L.addonCompartment = "Addon Compartment"
--L.craftingOrder = "Crafting Order (When Available)"

-- Coordinates.lua
--L.updateRate = "Update Rate (seconds)"
--L.updateRateDesc = "The lower the value, the faster the coordinates will update, but the more memory and CPU will be consumed due to asking the game for fresh coordinate data."
--L.Precision = "Precision"

-- Movers.lua
--L.moversDescription = "Enable the ability to move specific UI elements."
--L.disableWarning = "Disabling this will temporarily show the loading screen. Are you sure?"
--L.enableObject = "Enable %s"
--L.lockObject = "Lock %s"
L.pvpCaptureBar = "PvP 佔領狀態條"
--L.buffs = "Buffs/Debuffs"
--L.topCenterObjectivesWidget = "Top-Screen Objective/PvP Tracker"
--L.zoneTextCombatClick = "|cFF33FF99SexyMap|r: To toggle the World Map in combat, you must enable the feature in the Zone Text options."
--L.zoneTextSecureButtonEnable = "Allow clicking in combat"
--L.zoneTextSecureButtonEnableDesc = "Normally you can click the Zone Text to toggle your World Map, but not in combat without this feature enabled.\n\n|cffff0000WARNING!|r Don't enable this feature unless you understand what it does. Turning this on will prevent ALL of your addons from making certain changes to your minimap in combat, such as moving it or hiding it."
L.none = "無"
L.thin = "細"
L.thick = "粗"
L.outline = "輪廓"
L.monochrome = "單一顏色"
L.monochromeDesc = "切換為單一顏色，移除全部字型邊緣平滑。"
